@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 """Command line interface for Axonius API Client."""
-from ...constants import CONFIG_TYPES
-
-# from ...api.parsers.tables import tablize_adapters
+from ...constants.adapters import CONFIG_TYPES
 from ...tools import json_dump
 from ..context import click
 
