@@ -32,6 +32,6 @@ def cmd(ctx, url, key, secret, **kwargs):
     client = ctx.obj.start_client(url=url, key=key, secret=secret)
 
     with ctx.obj.exc_wrap(wraperror=ctx.obj.wraperror):
-        data = client.system.roles.get()
+        data = client.system_roles.get()
 
     handle_export(ctx=ctx, data=data, **kwargs)
