@@ -7,7 +7,7 @@ import click
 
 import axonius_api_client as axonapi
 
-from ...constants import PY36
+from ...constants.general import PY36
 from ...tools import echo_error, json_reload, pathlib
 from ..context import CONTEXT_SETTINGS
 from ..options import AUTH, add_options
@@ -23,10 +23,14 @@ API Objects:
     - devices/d: Work with device assets
     - users/u: Work with user assets
     - adapters/a: Work with adapters and adapter connections
-    - system/s: Work with users, roles, global settings, and more
     - dashboard/db: Work with dashboards and discovery cycle
     - instances/i: Work with instances
-    - jdump/j: Helper function to pretty print python objects
+    - system_users/su: Work with system users
+    - system_roles/sr: Work with system roles
+    - meta/m: Work with instance metadata
+    - settings_global/sgl: Work with Global system settings
+    - settings_gui/sgu: Work with GUI system settings
+    - settings_lifecycle/sl: Work with Lifecyle system settings
 """
 
 SHELL_EXIT = """Goodbye human. We hope you enjoyed your stay."""
@@ -60,6 +64,12 @@ def cmd(ctx, url, key, secret):  # noqa: D301
         - system/s: Work with users, roles, global settings, and more
         - dashboard/db: Work with dashboards and discovery cycle
         - instances/i: Work with instances
+        - system_users/su: Work with system users
+        - system_roles/sr: Work with system roles
+        - meta/m: Work with instance metadata
+        - settings_global/sgl: Work with Global system settings
+        - settings_gui/sgu: Work with GUI system settings
+        - settings_lifecycle/sl: Work with Lifecyle system settings
         - jdump/j: Helper function to pretty print python objects
 
     """
@@ -77,8 +87,13 @@ def cmd(ctx, url, key, secret):  # noqa: D301
         "enforcements": client.enforcements,
         "instances": client.instances,
         "jdump": jdump,
-        "system": client.system,
         "users": client.users,
+        "system_users": client.system_users,
+        "system_roles": client.system_roles,
+        "meta": client.meta,
+        "settings_global": client.settings_global,
+        "settings_gui": client.settings_gui,
+        "settings_lifecycle": client.settings_lifecycle,
         "a": client.adapters,
         "c": client,
         "d": client.devices,
@@ -86,8 +101,13 @@ def cmd(ctx, url, key, secret):  # noqa: D301
         "e": client.enforcements,
         "i": client.instances,
         "j": jdump,
-        "s": client.system,
         "u": client.users,
+        "su": client.system_users,
+        "sr": client.system_roles,
+        "m": client.meta,
+        "sgl": client.settings_global,
+        "sgu": client.settings_gui,
+        "sl": client.settings_lifecycle,
     }
 
     spawn_shell(shellvars)
