@@ -5,8 +5,6 @@ import pytest
 
 from axonius_api_client.exceptions import ApiError, NotFoundError
 
-# from ...meta import TEST_PERM, TEST_ROLE
-
 GUI_SECTION_WITH_SUBS = "system_settings"
 GUI_SECTION_NO_SUBS = "ldap_login_settings"
 GUI_NON_SUB_SECTION = "exactSearch"
@@ -68,8 +66,8 @@ class SettingsBasePublic:
 
 class TestSettingsGui(SettingsBasePublic):
     @pytest.fixture(scope="class")
-    def apiobj(self, api_system):
-        return api_system.settings_gui
+    def apiobj(self, api_settings_gui):
+        return api_settings_gui
 
     def test_get_section_full_config_true(self, apiobj):
         result = apiobj.get_section(section=GUI_SECTION_WITH_SUBS, full_config=True)
@@ -148,13 +146,13 @@ class TestSettingsGui(SettingsBasePublic):
         assert reset_value == old_value and reset_value != new_value
 
 
-class TestSettingsCore(SettingsBasePublic):
+class TestSettingsGlobal(SettingsBasePublic):
     @pytest.fixture(scope="class")
-    def apiobj(self, api_system):
-        return api_system.settings_core
+    def apiobj(self, api_settings_global):
+        return api_settings_global
 
 
 class TestSettingsLifecycle(SettingsBasePublic):
     @pytest.fixture(scope="class")
-    def apiobj(self, api_system):
-        return api_system.settings_lifecycle
+    def apiobj(self, api_settings_lifecycle):
+        return api_settings_lifecycle
